@@ -1,5 +1,6 @@
 import logging
 import time
+from typing import Optional
 
 
 class TimeFormatter(logging.Formatter):
@@ -9,9 +10,9 @@ class TimeFormatter(logging.Formatter):
     """
 
     def formatTime(
-        self, record: logging.LogRecord, datefmt: str = None
+        self, record: logging.LogRecord, datefmt: Optional[str] = None
     ) -> str:
-        ct = self.converter(record.created)  # type: ignore
+        ct = self.converter(record.created)
         if datefmt:
             if "%F" in datefmt:
                 msec = "%03d" % record.msecs
